#' Set reports folder structure
#'
#' @param path Destination folder for reports and templates
#' @param overwrite Allow overwriting templates folder
#'
#' @return Use for side effect.
#' @export
#'
#' @examples
#' # Create structure for reports
#' path <- tempdir()
#' create_reports(path)
#' list.files(path, recursive = TRUE)
#'
#' # Add a new report
#' report_path <- add_report("my_report", path)
#' list.files(report_path)
create_reports <- function(path = ".", overwrite = FALSE) {
  # Copy templates
  if (dir.exists(file.path(path, "templates"))) {
    if (overwrite) {
      warning("Folder ", file.path(path, "templates"), " is overwritten")
    } else {
      stop("Folder ", file.path(path, "templates"), " already exists")
    }
  }
  file.copy(from = pkg_sys("templates"),
            to = path,
            recursive = TRUE,
            copy.date = TRUE)

  # Create reports folder
  file.copy(from = pkg_sys("reports"),
            to = path,
            recursive = TRUE,
            copy.date = TRUE)
  invisible()
}
